==> layoutstudio-6.x-2.8.tar.gz: layoutstudio/templates/page.tpl.php <==
<?php
// $Id:
?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">
<head>
	<title><?php print $head_title; ?></title>
	<?php print $head; ?>
	<?php print $styles; ?>
  <?php print $layoutstudio_layout_styles; ?>
	<?php print $scripts; ?>
</head>

<body id="<?php print 'lang-' . $language->language; ?>" class="<?php print $body_classes;?>">
	<?php if (!empty($admin)) print $admin; ?> 

	<?php print $skip_to_links; ?>

	<div id="page">

		<div id="header" class="region clearfix">
			<div class="inside">

				<?php if ($logo): //Remember to enable in your theme's info file ?>
					<?php if ($is_front): ?>
						<img src="<?php print check_url($logo); ?>" alt="<?php print $site_name; ?> logo" />
					<?php else: ?>
						<a title="<?php print $site_name . ' Home';?>" href="<?php print $base_path; ?>">
							<img src="<?php print check_url($logo); ?>" alt="<?php print $site_title; ?>" />
						</a>
					<?php endif; ?>
				<?php endif; ?>
			
				<?php if ($is_front): ?>
					<?php if ($site_name): print '<p class="site-name">' . $site_name . '</p>'; endif; ?>
				<?php else: ?>
					<?php if ($site_name): print '<p class="site-name"><a title="' . $site_name . ' Home" href="' . $base_path . '">' . $site_name . '</a></p>'; endif; ?>
				<?php endif; ?>
				<?php if ($site_slogan): print '<p class="site-slogan">' . $site_slogan . '</p>'; endif; ?>
				<?php print $header; ?>
			</div>
		</div><!-- ID header -->

		<div id="container" class="clearfix">
									
			<div id="breadcrumb"><?php if ($breadcrumb): print $breadcrumb; endif; ?></div>

			<?php if ($preface_first OR $preface OR $preface_last): ?>
				<div id="preface">
					<?php if ($preface_first): ?>
			    	<div class="first region">
			      	<?php print $preface_first; ?>
			      </div><!-- CLASS first region -->
			    <?php endif; ?>
			    <?php if ($preface): ?>
			    	<div class="middle region">
			      	<?php print $preface; ?>
			      </div><!-- CLASS middle region -->
			    <?php endif; ?>
			    <?php if ($preface_last): ?>
			    	<div class="last region">
			      	<?php print $preface_last; ?>
			      </div><!-- CLASS last region -->
			    <?php endif; ?>
				</div><!-- ID preface -->
			<?php endif; ?>
		
			<div id="wrapper">
				<div id="primary">
		      <div class="inside clearfix">
		
		      <?php if ($content_pre_title): ?>
		      	<div id="content_pre_title" class="region">
			      	<?php print $content_pre_title; ?>
			      </div><!-- ID content_pre_title -->
			    <?php endif; ?>
		
					<a id="content-area"></a>
		      <?php if ($tabs): print '<div id="tabs-wrapper">'; endif; ?>
		      <?php if ($title): print '<h1 class="page-title'. ($tabs ? ' with-tabs' : '') . ($content_pre_title ? ' pre-title' : '') . ($content_post_title ? ' post-title' : '') .'">'. $title .'</h1>'; endif; ?>
		      <?php if ($tabs): print $tabs .'</div>'; endif; ?>
		      <?php if (isset($tabs2)): print $tabs2; endif; ?>
		      <?php if ($help): print $help; endif; ?>
		      <?php if ($messages): print $messages; endif; ?>
		
		      <?php if ($content_post_title): ?>
		      	<div id="content-post-title" class="region">
			      	<?php print $content_post_title; ?>
			      </div><!-- ID content_post_title -->
			    <?php endif; ?>
		
		      <?php print $content ?>
					
		      <?php print $feed_icons ?>
		      </div><!-- CLASS primary -->
				</div><!-- ID primary -->
			</div><!-- ID wrapper -->
			
			<?php if ($secondary_first OR $secondary OR $secondary_last): ?>
				<div id="secondary" class="clearfix">
					<?php if ($secondary_first): ?>
			    	<div class="first region">
			      	<?php print $secondary_first; ?>
			      </div><!-- CLASS first region -->
			    <?php endif; ?>
			    <?php if ($secondary): ?>
			    	<div class="middle region">
			      	<?php print $secondary; ?>
			      </div><!-- CLASS middle region -->
			    <?php endif; ?>
			    <?php if ($secondary_last): ?>
			    	<div class="last region">
			      	<?php print $secondary_last; ?>
			      </div><!-- CLASS last region -->
			    <?php endif; ?>
				</div><!-- ID secondary -->
			<?php endif; ?>
		
			<?php if ($tertiary_first OR $tertiary OR $tertiary_last): ?>
				<div id="tertiary" class="clearfix">
					<?php if ($tertiary_first): ?>
			    	<div class="first region">
			      	<?php print $tertiary_first; ?>
			      </div><!-- CLASS first region -->
			    <?php endif; ?>
			    <?php if ($tertiary): ?>
			    	<div class="middle region">
			      	<?php print $tertiary; ?>
			      </div><!-- CLASS middle region -->
			    <?php endif; ?>
			    <?php if ($tertiary_last): ?>
			    	<div class="last region">
			      	<?php print $tertiary_last; ?>
			      </div><!-- CLASS last region -->
			    <?php endif; ?>
				</div><!-- ID tertiary -->
			<?php endif; ?>
	
			<?php if ($postscript_first OR $postscript OR $postscript_last): ?>
				<div id="postscript">
					<?php if ($postscript_first): ?>
			    	<div class="first region">
			      	<?php print $postscript_first; ?>
			      </div><!-- CLASS first region -->
			    <?php endif; ?>
			    <?php if ($postscript): ?>
			    	<div class="middle region">
			      	<?php print $postscript; ?>
			      </div><!-- CLASS middle region -->
			    <?php endif; ?>
			    <?php if ($postscript_last): ?>
			    	<div class="last region">
			      	<?php print $postscript_last; ?>
			      </div><!-- CLASS last region -->
			    <?php endif; ?>
				</div><!-- ID postscript -->
			<?php endif; ?>
			
			<?php if ($navigation OR $primary_links OR $secondary_links): ?>
			<div id="navigation">
				<a id="nav"></a>
				
					<?php if (isset($primary_links)) : //Remember to enable in your theme's info file ?>
	          <?php print theme('links', $primary_links, array('class' => 'links primary-links')) ?>
	        <?php endif; ?>
	        <?php if (isset($secondary_links)) :  //Remember to enable in your theme's info file  ?>
	          <?php print theme('links', $secondary_links, array('class' => 'links secondary-links')) ?>
	        <?php endif; ?>
        
        	<?php print $navigation; ?>

			</div><!-- ID navigation -->
			<?php endif; ?>

		</div><!-- ID container -->
	
		<div id="footer" class="region  clearfix">
			<div class="inside">

				<?php print $footer ?>
				<p class="footer-message"><?php print $footer_message ?></p>

			</div><!-- CLASS inside -->
		</div><!-- ID footer -->
		
		<?php if ($closure_region): ?>
    	<div id="closure" class="region">
    		<?php print $closure_region; ?>
    	</div>
  	<?php endif; ?>
  
	</div><!-- ID page -->

	<?php print $closure ?>
	
</body>
</html>

==> layoutstudio-6.x-2.9.tar.gz: layoutstudio/templates/page.tpl.php <==
<?php
// $Id:
?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>" class="no-js">
<head>
	<title><?php print $head_title; ?></title>
	<?php print $head; ?>
	<?php print $styles; ?>
  <?php print $layoutstudio_layout_styles; ?>
	<?php print $scripts; ?>
</head>

<body id="<?php print 'lang-' . $language->language; ?>" class="<?php print $body_classes;?>">
	<?php if (!empty($admin)) print $admin; ?> 

	<?php print $skip_to_links; ?>

	<div id="page">

		<div id="header" class="region clearfix">
			<div class="inside">

				<?php if ($logo): ?>
					<?php if ($is_front): ?>
						<img src="<?php print check_url($logo); ?>" alt="<?php print $site_name; ?> logo" />
					<?php else: ?>
						<a title="<?php print $site_name . ' Home';?>" href="<?php print $base_path; ?>">
							<img src="<?php print check_url($logo); ?>" alt="<?php print $site_name; ?> logo" />
						</a>
					<?php endif; ?>
				<?php endif; ?>
			
				<?php if ($is_front): ?>
					<?php if ($site_name): print '<p class="site-name">' . $site_name . '</p>'; endif; ?>
				<?php else: ?>
					<?php if ($site_name): print '<p class="site-name"><a title="' . $site_name . ' Home" href="' . $base_path . '">' . $site_name . '</a></p>'; endif; ?>
				<?php endif; ?>
				<?php if ($site_slogan): print '<p class="site-slogan">' . $site_slogan . '</p>'; endif; ?>
				<?php print $header; ?>
			</div>
		</div><!-- ID header -->

		<div id="container" class="clearfix">
									
			<div id="breadcrumb"><?php if ($breadcrumb): print $breadcrumb; endif; ?></div>

			<?php if ($preface_first OR $preface OR $preface_last): ?>
				<div id="preface">
					<?php if ($preface_first): ?>
			    	<div class="first region">
			      	<?php print $preface_first; ?>
			      </div><!-- CLASS first region -->
			    <?php endif; ?>
			    <?php if ($preface): ?>
			    	<div class="middle region">
			      	<?php print $preface; ?>
			      </div><!-- CLASS middle region -->
			    <?php endif; ?>
			    <?php if ($preface_last): ?>
			    	<div class="last region">
			      	<?php print $preface_last; ?>
			      </div><!-- CLASS last region -->
			    <?php endif; ?>
				</div><!-- ID preface -->
			<?php endif; ?>
		
			<div id="wrapper">
				<div id="primary">
		      <div class="inside clearfix">
		
		      <?php if ($content_pre_title): ?>
		      	<div id="content_pre_title" class="region">
			      	<?php print $content_pre_title; ?>
			      </div><!-- ID content_pre_title -->
			    <?php endif; ?>
		
					<a id="content-area"></a>
		      <?php if ($tabs): print '<div id="tabs-wrapper">'; endif; ?>
		      <?php if ($title): print '<h1 class="page-title'. ($tabs ? ' with-tabs' : '') . ($content_pre_title ? ' pre-title' : '') . ($content_post_title ? ' post-title' : '') .'">'. $title .'</h1>'; endif; ?>
		      <?php if ($tabs): print $tabs .'</div>'; endif; ?>
		      <?php if (isset($tabs2)): print $tabs2; endif; ?>
		      <?php if ($help): print $help; endif; ?>
		      <?php if ($messages): print $messages; endif; ?>
		
		      <?php if ($content_post_title): ?>
		      	<div id="content-post-title" class="region">
			      	<?php print $content_post_title; ?>
			      </div><!-- ID content_post_title -->
			    <?php endif; ?>
		
		      <?php print $content ?>
					
		      <?php print $feed_icons ?>
		      </div><!-- CLASS primary -->
				</div><!-- ID primary -->
			</div><!-- ID wrapper -->
			
			<?php if ($secondary_first OR $secondary OR $secondary_last): ?>
				<div id="secondary" class="clearfix">
					<?php if ($secondary_first): ?>
			    	<div class="first region">
			      	<?php print $secondary_first; ?>
			      </div><!-- CLASS first region -->
			    <?php endif; ?>
			    <?php if ($secondary): ?>
			    	<div class="middle region">
			      	<?php print $secondary; ?>
			      </div><!-- CLASS middle region -->
			    <?php endif; ?>
			    <?php if ($secondary_last): ?>
			    	<div class="last region">
			      	<?php print $secondary_last; ?>
			      </div><!-- CLASS last region -->
			    <?php endif; ?>
				</div><!-- ID secondary -->
			<?php endif; ?>
		
			<?php if ($tertiary_first OR $tertiary OR $tertiary_last): ?>
				<div id="tertiary" class="clearfix">
					<?php if ($tertiary_first): ?>
			    	<div class="first region">
			      	<?php print $tertiary_first; ?>
			      </div><!-- CLASS first region -->
			    <?php endif; ?>
			    <?php if ($tertiary): ?>
			    	<div class="middle region">
			      	<?php print $tertiary; ?>
			      </div><!-- CLASS middle region -->
			    <?php endif; ?>
			    <?php if ($tertiary_last): ?>
			    	<div class="last region">
			      	<?php print $tertiary_last; ?>
			      </div><!-- CLASS last region -->
			    <?php endif; ?>
				</div><!-- ID tertiary -->
			<?php endif; ?>
	
			<?php if ($postscript_first OR $postscript OR $postscript_last): ?>
				<div id="postscript">
					<?php if ($postscript_first): ?>
			    	<div class="first region">
			      	<?php print $postscript_first; ?>
			      </div><!-- CLASS first region -->
			    <?php endif; ?>
			    <?php if ($postscript): ?>
			    	<div class="middle region">
			      	<?php print $postscript; ?>
			      </div><!-- CLASS middle region -->
			    <?php endif; ?>
			    <?php if ($postscript_last): ?>
			    	<div class="last region">
			      	<?php print $postscript_last; ?>
			      </div><!-- CLASS last region -->
			    <?php endif; ?>
				</div><!-- ID postscript -->
			<?php endif; ?>
			
			<?php if ($navigation OR $primary_links OR $secondary_links): ?>
			<div id="navigation">
				<a id="nav"></a>
				
					<?php if (isset($primary_links)): ?>
	          <?php print theme('links', $primary_links, array('class' => 'links primary-links')) ?>
	        <?php endif; ?>
	        <?php if (isset($secondary_links)): ?>
	          <?php print theme('links', $secondary_links, array('class' => 'links secondary-links')) ?>
	        <?php endif; ?>
        
        	<?php print $navigation; ?>

			</div><!-- ID navigation -->
			<?php endif; ?>

		</div><!-- ID container -->
	
		<div id="footer" class="region  clearfix">
			<div class="inside">

				<?php print $footer ?>
				<p class="footer-message"><?php print $footer_message ?></p>

			</div><!-- CLASS inside -->
		</div><!-- ID footer -->
		
		<?php if ($closure_region): ?>
    	<div id="closure" class="region">
    		<?php print $closure_region; ?>
    	</div>
  	<?php endif; ?>
  
	</div><!-- ID page -->

	<?php print $closure ?>
	
</body>
</html>
